@@ -26,10 +26,6 @@ class AtlassianRestAPI(object):
     def __init__(self, url, username=None, password=None, timeout=60, api_root='rest/api', api_version='latest',
                  verify_ssl=True, session=None, oauth=None, cookies=None, advanced_mode=None, kerberos=None,
                  cloud=False, proxies=None):
-        if ('atlassian.net' in url or 'jira.com' in url) \
-                and '/wiki' not in url \
-                and self.__class__.__name__ in 'Confluence':
-            url = self.url_joiner(url, '/wiki')
         self.url = url
         self.username = username
         self.password = password
@@ -54,6 +50,12 @@ class AtlassianRestAPI(object):
         elif cookies is not None:
             self._session.cookies.update(cookies)
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *_):
+        self.close()
+
     def _create_basic_session(self, username, password):
         self._session.auth = (username, password)
 
@@ -89,6 +91,17 @@ class AtlassianRestAPI(object):
         """
         self._session.headers.update({key: value})
 
+    @staticmethod
+    def _response_handler(response):
+        try:
+            return response.json()
+        except ValueError:
+            log.debug('Received response with no content')
+            return None
+        except Exception as e:
+            log.error(e)
+            return None
+
     def log_curl_debug(self, method, url, data=None, headers=None, level=logging.DEBUG):
         """
 
@@ -117,6 +130,9 @@ class AtlassianRestAPI(object):
             url_link += '/'
         return url_link
 
+    def close(self):
+        return self._session.close()
+
     def request(self, method='GET', path='/', data=None, json=None, flags=None, params=None, headers=None,
                 files=None, trailing=None):
         """
@@ -199,28 +215,15 @@ class AtlassianRestAPI(object):
                                 trailing=trailing)
         if self.advanced_mode:
             return response
-        try:
-            return response.json()
-        except ValueError:
-            log.debug('Received response with no content')
-            return None
-        except Exception as e:
-            log.error(e)
-            return None
+        return self._response_handler(response)
 
     def put(self, path, data=None, headers=None, files=None, trailing=None, params=None):
         response = self.request('PUT', path=path, data=data, headers=headers, files=files, params=params,
                                 trailing=trailing)
         if self.advanced_mode:
             return response
-        try:
-            return response.json()
-        except ValueError:
-            log.debug('Received response with no content')
-            return None
-        except Exception as e:
-            log.error(e)
-            return None
+        return self._response_handler(response)
+
 
     def delete(self, path, data=None, headers=None, params=None, trailing=None):
         """
@@ -232,11 +235,4 @@ class AtlassianRestAPI(object):
         response = self.request('DELETE', path=path, data=data, headers=headers, params=params, trailing=trailing)
         if self.advanced_mode:
             return response
-        try:
-            return response.json()
-        except ValueError:
-            log.debug('Received response with no content')
-            return None
-        except Exception as e:
-            log.error(e)
-            return None
+        return self._response_handler(response)
